==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/DisasterRecoveryConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin

import com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Single item in List or Get Alias(Disaster Recovery configuration) operation
 * Azure REST API version: 2022-10-01-preview. Prior API version in Azure Native 1.x: 2017-04-01.
 * Other available API versions: 2023-01-01-preview, 2024-01-01.
 * ## Example Usage
 * ### EHAliasCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var disasterRecoveryConfig = new AzureNative.EventHub.DisasterRecoveryConfig("disasterRecoveryConfig", new()
 *     {
 *         Alias = "sdk-DisasterRecovery-3814",
 *         NamespaceName = "sdk-Namespace-8859",
 *         PartnerNamespace = "sdk-Namespace-37",
 *         ResourceGroupName = "exampleResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/eventhub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := eventhub.NewDisasterRecoveryConfig(ctx, "disasterRecoveryConfig", &eventhub.DisasterRecoveryConfigArgs{
 * 			Alias:             pulumi.String("sdk-DisasterRecovery-3814"),
 * 			NamespaceName:     pulumi.String("sdk-Namespace-8859"),
 * 			PartnerNamespace:  pulumi.String("sdk-Namespace-37"),
 * 			ResourceGroupName: pulumi.String("exampleResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.eventhub.DisasterRecoveryConfig;
 * import com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var disasterRecoveryConfig = new DisasterRecoveryConfig("disasterRecoveryConfig", DisasterRecoveryConfigArgs.builder()
 *             .alias("sdk-DisasterRecovery-3814")
 *             .namespaceName("sdk-Namespace-8859")
 *             .partnerNamespace("sdk-Namespace-37")
 *             .resourceGroupName("exampleResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:eventhub:DisasterRecoveryConfig sdk-DisasterRecovery-3814 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.EventHub/namespaces/{namespaceName}/disasterRecoveryConfigs/{alias}
 * ```
 * @property alias The Disaster Recovery configuration name
 * @property alternateName Alternate name specified when alias and namespace names are same.
 * @property namespaceName The Namespace name
 * @property partnerNamespace ARM Id of the Primary/Secondary eventhub namespace name, which is part of GEO DR pairing
 * @property resourceGroupName Name of the resource group within the azure subscription.
 */
public data class DisasterRecoveryConfigArgs(
    public val alias: Output<String>? = null,
    public val alternateName: Output<String>? = null,
    public val namespaceName: Output<String>? = null,
    public val partnerNamespace: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs =
        com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs.builder()
            .alias(alias?.applyValue({ args0 -> args0 }))
            .alternateName(alternateName?.applyValue({ args0 -> args0 }))
            .namespaceName(namespaceName?.applyValue({ args0 -> args0 }))
            .partnerNamespace(partnerNamespace?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DisasterRecoveryConfigArgs].
 */
@PulumiTagMarker
public class DisasterRecoveryConfigArgsBuilder internal constructor() {
    private var alias: Output<String>? = null

    private var alternateName: Output<String>? = null

    private var namespaceName: Output<String>? = null

    private var partnerNamespace: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    /**
     * @param value The Disaster Recovery configuration name
     */
    @JvmName("ttjdtfqkphbqgnus")
    public suspend fun alias(`value`: Output<String>) {
        this.alias = value
    }

    /**
     * @param value Alternate name specified when alias and namespace names are same.
     */
    @JvmName("kjitwnnbnsbufbif")
    public suspend fun alternateName(`value`: Output<String>) {
        this.alternateName = value
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("mskrdrpmfwueyiql")
    public suspend fun namespaceName(`value`: Output<String>) {
        this.namespaceName = value
    }

    /**
     * @param value ARM Id of the Primary/Secondary eventhub namespace name, which is part of GEO DR pairing
     */
    @JvmName("rjcmgsbhxfeonute")
    public suspend fun partnerNamespace(`value`: Output<String>) {
        this.partnerNamespace = value
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("fwntykmfoorftrtf")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The Disaster Recovery configuration name
     */
    @JvmName("ljgeclrgijulskkp")
    public suspend fun alias(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alias = mapped
    }

    /**
     * @param value Alternate name specified when alias and namespace names are same.
     */
    @JvmName("lwupeexhfebvghfx")
    public suspend fun alternateName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alternateName = mapped
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("bpcvtbcddwhyjmjq")
    public suspend fun namespaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespaceName = mapped
    }

    /**
     * @param value ARM Id of the Primary/Secondary eventhub namespace name, which is part of GEO DR pairing
     */
    @JvmName("lboxgaspiextcusl")
    public suspend fun partnerNamespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerNamespace = mapped
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("hnsyxbeuwxhshwnd")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    internal fun build(): DisasterRecoveryConfigArgs = DisasterRecoveryConfigArgs(
        alias = alias,
        alternateName = alternateName,
        namespaceName = namespaceName,
        partnerNamespace = partnerNamespace,
        resourceGroupName = resourceGroupName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/DisasterRecoveryConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin

import com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Single item in List or Get Alias(Disaster Recovery configuration) operation
 * Azure REST API version: 2022-10-01-preview. Prior API version in Azure Native 1.x: 2017-04-01.
 * Other available API versions: 2023-01-01-preview, 2024-01-01.
 * ## Example Usage
 * ### EHAliasCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var disasterRecoveryConfig = new AzureNative.EventHub.DisasterRecoveryConfig("disasterRecoveryConfig", new()
 *     {
 *         Alias = "sdk-DisasterRecovery-3814",
 *         NamespaceName = "sdk-Namespace-8859",
 *         PartnerNamespace = "sdk-Namespace-37",
 *         ResourceGroupName = "exampleResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/eventhub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := eventhub.NewDisasterRecoveryConfig(ctx, "disasterRecoveryConfig", &eventhub.DisasterRecoveryConfigArgs{
 * 			Alias:             pulumi.String("sdk-DisasterRecovery-3814"),
 * 			NamespaceName:     pulumi.String("sdk-Namespace-8859"),
 * 			PartnerNamespace:  pulumi.String("sdk-Namespace-37"),
 * 			ResourceGroupName: pulumi.String("exampleResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.eventhub.DisasterRecoveryConfig;
 * import com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var disasterRecoveryConfig = new DisasterRecoveryConfig("disasterRecoveryConfig", DisasterRecoveryConfigArgs.builder()
 *             .alias("sdk-DisasterRecovery-3814")
 *             .namespaceName("sdk-Namespace-8859")
 *             .partnerNamespace("sdk-Namespace-37")
 *             .resourceGroupName("exampleResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:eventhub:DisasterRecoveryConfig sdk-DisasterRecovery-3814 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.EventHub/namespaces/{namespaceName}/disasterRecoveryConfigs/{alias}
 * ```
 * @property alias The Disaster Recovery configuration name
 * @property alternateName Alternate name specified when alias and namespace names are same.
 * @property namespaceName The Namespace name
 * @property partnerNamespace ARM Id of the Primary/Secondary eventhub namespace name, which is part of GEO DR pairing
 * @property resourceGroupName Name of the resource group within the azure subscription.
 */
public data class DisasterRecoveryConfigArgs(
    public val alias: Output<String>? = null,
    public val alternateName: Output<String>? = null,
    public val namespaceName: Output<String>? = null,
    public val partnerNamespace: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs =
        com.pulumi.azurenative.eventhub.DisasterRecoveryConfigArgs.builder()
            .alias(alias?.applyValue({ args0 -> args0 }))
            .alternateName(alternateName?.applyValue({ args0 -> args0 }))
            .namespaceName(namespaceName?.applyValue({ args0 -> args0 }))
            .partnerNamespace(partnerNamespace?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DisasterRecoveryConfigArgs].
 */
@PulumiTagMarker
public class DisasterRecoveryConfigArgsBuilder internal constructor() {
    private var alias: Output<String>? = null

    private var alternateName: Output<String>? = null

    private var namespaceName: Output<String>? = null

    private var partnerNamespace: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    /**
     * @param value The Disaster Recovery configuration name
     */
    @JvmName("rgkrocttbpqbxenp")
    public suspend fun alias(`value`: Output<String>) {
        this.alias = value
    }

    /**
     * @param value Alternate name specified when alias and namespace names are same.
     */
    @JvmName("wxrmrroyoiyufucj")
    public suspend fun alternateName(`value`: Output<String>) {
        this.alternateName = value
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("vtadewpjmmxwhtaj")
    public suspend fun namespaceName(`value`: Output<String>) {
        this.namespaceName = value
    }

    /**
     * @param value ARM Id of the Primary/Secondary eventhub namespace name, which is part of GEO DR pairing
     */
    @JvmName("vvppffvpnlqkrfev")
    public suspend fun partnerNamespace(`value`: Output<String>) {
        this.partnerNamespace = value
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("iocbvdbqwoxojrib")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The Disaster Recovery configuration name
     */
    @JvmName("mbxfyumlkxbwwbks")
    public suspend fun alias(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alias = mapped
    }

    /**
     * @param value Alternate name specified when alias and namespace names are same.
     */
    @JvmName("kgflriwnshomavre")
    public suspend fun alternateName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.alternateName = mapped
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("xvwwekhsudvrvhqu")
    public suspend fun namespaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespaceName = mapped
    }

    /**
     * @param value ARM Id of the Primary/Secondary eventhub namespace name, which is part of GEO DR pairing
     */
    @JvmName("yvyfbjepfgewtudk")
    public suspend fun partnerNamespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerNamespace = mapped
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("aqtrwdmlgedpntdf")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    internal fun build(): DisasterRecoveryConfigArgs = DisasterRecoveryConfigArgs(
        alias = alias,
        alternateName = alternateName,
        namespaceName = namespaceName,
        partnerNamespace = partnerNamespace,
        resourceGroupName = resourceGroupName,
    )
}
